# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Describetable(Component):
    """A Describetable component.
ExampleComponent is an example component.
It takes a property, `label`, and
displays it.
It renders an input with the property `value`
which is editable by the user.

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- buttonText (string; optional)

- classAppendix (string; optional)

- data (a list of or a singular dash component, string or number; optional)

- label (string; required):
    A label that will be printed when this component is rendered.

- value (dict; optional):
    The value displayed in the input."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, label=Component.REQUIRED, value=Component.UNDEFINED, data=Component.UNDEFINED, classAppendix=Component.UNDEFINED, buttonText=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'buttonText', 'classAppendix', 'data', 'label', 'value']
        self._type = 'Describetable'
        self._namespace = 'describetable'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'buttonText', 'classAppendix', 'data', 'label', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in ['label']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Describetable, self).__init__(**args)
